<?php
/**
 * @file infusionsoft.admin.inc
 * Admin Settings for Infusionsoft.
 */

/**
 * Admin Settings Form Callback
 */
function infusionsoft_admin_settings() {
  $form = array();

  $form['infusionsoft_app_name'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('infusionsoft_app_name', ''),
    '#description' => '',
    '#title' => 'Infusionsoft Application Name (domain prefix)',
    '#required' => TRUE,
  );
  $form['infusionsoft_api_key'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('infusionsoft_api_key', ''),
    '#description' => '',
    '#title' => 'Infusionsoft API Key',
    '#required' => TRUE,
  );

  return system_settings_form($form);
}

/**
 * User Contact Form
 */
function infusionsoft_user_contact_form($form, &$form_state, $user) {

  $form = array(
    '#prefix' => '<div id="infusionsoft-user-widget">',
    '#suffix' => '</div>',
  );

  $infusionsoft_id = infusionsoft_contact_id($user, FALSE);

  if (!$infusionsoft_id) {
    $form['quick_add'] = array(
      '#type' => 'fieldset',
      '#title' => 'Add User to Infusionsoft',
    );
    $form['quick_add']['add'] = array(
      '#type' => 'submit',
      '#value' => 'Add to Infusionsoft',
      '#submit' => array('infusionsoft_user_form_submit'),
      '#name' => 'add_user',
      '#ajax' => array(
        'wrapper' => 'infusionsoft-user-widget',
        'callback' => 'infusionsoft_user_form_js',
      ),
    );
  }
  else {
    $available_groups = infusionsoft_groups_options();
    $groups = infusionsoft_group_contact_options($infusionsoft_id);

    $form['quick_add'] = array(
      '#type' => 'fieldset',
      '#title' => 'Remove User from Infusionsoft',
    );
    $form['quick_add']['user_id'] = array(
      '#markup' => t('User is infusionsoft Contact# !contact_num', array('!contact_num' => $infusionsoft_id)),
      '#prefix' => '<div>',
      '#suffix' => '</div>',
    );

    $live_link = 'https://' . variable_get('infusionsoft_app_name', '') . '.infusionsoft.com/Contact/manageContact.jsp';

    $form['quick_add']['user_link'] = array(
      '#markup' => l(
        t('View User in Infusionsoft'), $live_link, array(
        'query' => array('view' => 'edit', 'ID' => $infusionsoft_id),
        'attributes' => array('target' => '_blank'),
        )
      ),
      '#prefix' => '<div>',
      '#suffix' => '</div>',
    );

    if ($groups) {
      $form['groups'] = array(
        '#type' => 'fieldset',
        '#title' => 'Current Infusionsoft Groups (Tags)',
      );

      $group_rows = array();
      foreach ($groups as $group) {

        unset($available_groups[$group['GroupId']]);

        $form['groups'][$group['GroupId']] = array(
          '#type' => 'submit',
          '#value' => t('Remove from Group'),
          '#submit' => array('infusionsoft_user_form_submit'),
          '#name' => 'remove_group_' . $group['GroupId'],
        );

        $group_rows[$group['GroupId']] = array(
          $group['ContactGroup'],
          format_date(strtotime($group['DateCreated']->iso8601)),
          drupal_render($form['groups'][$group['GroupId']]),
        );
      }
      $form['groups']['group_table'] = array(
        '#theme' => 'table',
        '#header' => array(t('Group (Tag)'), t('Date Added'), t('Remove')),
        '#rows' => $group_rows,
      );
    }

    if ($available_groups) {
      $form['available_groups'] = array(
        '#type' => 'fieldset',
        '#title' => 'Available Infusionsoft Groups (Tags)',
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
      );

      $group_rows = array();
      foreach ($available_groups as $id => $group) {

        $form['available_groups'][$id] = array(
          '#type' => 'submit',
          '#value' => t('Add to Group'),
          '#submit' => array('infusionsoft_user_form_submit'),
          '#name' => 'add_group_' . $id,
        );

        $group_rows[$id] = array(
          $group . ' (ID: ' . $id . ')',
          drupal_render($form['available_groups'][$id]),
        );
      }
      $form['available_groups']['group_table'] = array(
        '#theme' => 'table',
        '#header' => array(t('Group (Tag)'), t('Add')),
        '#rows' => $group_rows,
      );
    }
  }

  $form_state['user'] = $user;

  return $form;
}

/**
 * User Form JS
 */
function infusionsoft_user_form_js($form, $form_state) {
  return $form;
}

/**
 * User Form Submit Handler
 */
function infusionsoft_user_form_submit($form, &$form_state) {

  $action = $form_state['triggering_element']['#name'];

  if ($action === 'add_user') {
    $infusionsoft_id = infusionsoft_user_to_contact($form_state['user']);
  }
  else {
    $infusionsoft_id = infusionsoft_contact_id($form_state['user']);
  }

  if (strpos($action, "remove_group_") !== FALSE) {
    $group_id = str_replace("remove_group_", "", $action);
    $action = "remove_group";
  }

  if (strpos($action, "add_group_") !== FALSE) {
    $group_id = str_replace("add_group_", "", $action);
    $action = "add_group";
  }

  switch ($action) {
    case 'remove_group':
      if (infusionsoft_user_op("remove", "group", $infusionsoft_id, $group_id)) {
        cache_set('infusionsoft:membership:group:' . $infusionsoft_id, FALSE);
        drupal_set_message(t("User Removed from Group"));
      }
      break;
    case 'add_group':
      if (infusionsoft_user_op("add", "group", $infusionsoft_id, $group_id)) {
        cache_set('infusionsoft:membership:group:' . $infusionsoft_id, FALSE);
        drupal_set_message(t("User Added to Group"));
      }
      break;
  }

  $form_state['rebuild'] = TRUE;
}
